@@ -36,6 +36,9 @@
 #include <yaz/srw.h>
 #include <yaz/cookie.h>
 #include <yaz/mutex.h>
+#if HAVE_LIBMEMCACHED_MEMCACHED_H
+#include <libmemcached/memcached.h>
+#endif
 
 #define SHPTR 1
 
@@ -108,6 +111,9 @@ struct ZOOM_connection_p {
     int log_details;
     int log_api;
     WRBUF saveAPDU_wrbuf;
+#if HAVE_LIBMEMCACHED_MEMCACHED_H
+    memcached_st *mc_st;
+#endif
 };
 
 typedef struct ZOOM_record_cache_p *ZOOM_record_cache;
@@ -133,9 +139,12 @@ struct ZOOM_resultset_p {
     struct WRBUF_shptr *record_wrbuf;
 #endif
     ZOOM_resultset next;
-    ZOOM_facet_field *facets;
-    int num_facets;
-    char **facets_names;
+    char *req_facets;
+    ZOOM_facet_field *res_facets;
+    int num_res_facets;
+    char **facets_names; /* redundant. For ZOOM_resultset_facets_names only */
+    WRBUF mc_key;
+    int live_set; /* 0=no hit count, 1=cached hit, 2=hits + real set */
 };
 
 struct facet_term_p {
@@ -183,17 +192,7 @@ struct ZOOM_task_p {
             char *syntax;
             char *elementSetName;
             char *schema;
-            int recv_search_fired;
         } search;
-#define ZOOM_TASK_RETRIEVE 2
-        struct {
-            int start;
-            ZOOM_resultset resultset;
-            int count;
-            char *syntax;
-            char *elementSetName;
-            char *schema;
-        } retrieve;
 #define ZOOM_TASK_CONNECT 3
 #define ZOOM_TASK_SCAN 4
         struct {
@@ -228,8 +227,7 @@ void ZOOM_set_error(ZOOM_connection c, int error, const char *addinfo);
 ZOOM_Event ZOOM_Event_create(int kind);
 void ZOOM_connection_put_event(ZOOM_connection c, ZOOM_Event event);
 
-zoom_ret ZOOM_connection_Z3950_send_search(ZOOM_connection c);
-zoom_ret send_Z3950_present(ZOOM_connection c);
+zoom_ret ZOOM_connection_Z3950_search(ZOOM_connection c);
 zoom_ret ZOOM_connection_Z3950_send_scan(ZOOM_connection c);
 zoom_ret ZOOM_send_buf(ZOOM_connection c);
 zoom_ret send_Z3950_sort(ZOOM_connection c, ZOOM_resultset resultset);
@@ -255,6 +253,7 @@ Z_Query *ZOOM_query_get_Z_Query(ZOOM_query s);
 Z_SortKeySpecList *ZOOM_query_get_sortspec(ZOOM_query s);
 const char *ZOOM_query_get_query_string(ZOOM_query s);
 const char *ZOOM_query_get_sru11(ZOOM_query s);
+void ZOOM_query_get_hash(ZOOM_query s, WRBUF w);
 
 int ZOOM_uri_to_code(const char *uri);
 
@@ -273,6 +272,31 @@ void ZOOM_Event_destroy(ZOOM_Event event);
 zoom_ret ZOOM_send_GDU(ZOOM_connection c, Z_GDU *gdu);
 void ZOOM_handle_facet_list(ZOOM_resultset r, Z_FacetList *fl);
 
+void ZOOM_memcached_init(ZOOM_connection c);
+int ZOOM_memcached_configure(ZOOM_connection c);
+void ZOOM_memcached_destroy(ZOOM_connection c);
+void ZOOM_memcached_resultset(ZOOM_resultset r, ZOOM_query q);
+void ZOOM_memcached_search(ZOOM_connection c, ZOOM_resultset r);
+void ZOOM_memcached_hitcount(ZOOM_connection c, ZOOM_resultset result,
+                             Z_OtherInformation *oi, const char *precision);
+void ZOOM_memcached_add(ZOOM_resultset r, Z_NamePlusRecord *npr,
+                        int pos,
+                        const char *syntax, const char *elementSetName,
+                        const char *schema,
+                        Z_SRW_diagnostic *diag);
+Z_NamePlusRecord *ZOOM_memcached_lookup(ZOOM_resultset r, int pos,
+                                        const char *syntax,
+                                        const char *elementSetName,
+                                        const char *schema);
+ZOOM_record ZOOM_record_cache_lookup_i(ZOOM_resultset r, int pos,
+                                       const char *syntax,
+                                       const char *elementSetName,
+                                       const char *schema);
+void ZOOM_handle_facet_result(ZOOM_connection c, ZOOM_resultset r,
+                              Z_OtherInformation *o);
+void ZOOM_handle_search_result(ZOOM_connection c, ZOOM_resultset resultset,
+                               Z_OtherInformation *o);
+
 /*
  * Local variables:
  * c-basic-offset: 4
